@@ -8,12 +8,20 @@ function(slicedata, ymaskdata)
 {
 	fbase <- slicedata$fbase
 	slice <- slicedata$slice
-  fsl.csf <- system.file(paste("data/",fbase,"_csf.nii.gz",sep=""),
-		package = "cudaBayesregData")
-  fsl.gry <- system.file(paste("data/",fbase,"_gry.nii.gz",sep=""),
-		package = "cudaBayesregData")
-  fsl.wht <- system.file(paste("data/",fbase,"_wht.nii.gz",sep=""),
-		package = "cudaBayesregData")
+  if(!is.null(fbase)) {
+    fsl.csf <- system.file(paste("extdata/",fbase,"_csf.nii.gz",sep=""),
+		  package = "cudaBayesregData")
+    fsl.gry <- system.file(paste("extdata/",fbase,"_gry.nii.gz",sep=""),
+		  package = "cudaBayesregData")
+    fsl.wht <- system.file(paste("extdata/",fbase,"_wht.nii.gz",sep=""),
+	  	package = "cudaBayesregData")
+  }
+  else {
+    fsl.csf <- "csf.nii.gz"
+    fsl.gry <- "gry.nii.gz"
+    fsl.wht <- "wht.nii.gz"
+  }
+  stopifnot(file.exists(fsl.csf), file.exists(fsl.gry), file.exists(fsl.wht))
   csfm.nifti <- readNIfTI(fsl.csf)
   csfm <- csfm.nifti@.Data
 	grym.nifti <- readNIfTI(fsl.gry)
